import React, { Component } from "react";
import Form from "react-jsonschema-form";

class FileWidget extends React.Component {
    state = {
        file: null
    }

    processFile = (files) => {
        console.log("processFile", files);
        const f = files[0];
        return new Promise((resolve, reject) => {
            const reader = new FileReader();
            reader.onload = (event) => resolve(event.target.result);
            reader.readAsDataURL(f);
        });
    }
    
    handleChange = event => {
        console.log(" handleChange event", event);
        console.log("handleChange ", URL.createObjectURL(event.target.files[0]));
        URL.revokeObjectURL(this.state.file); // removed old image to avoid memory issues

        this.processFile(event.target.files).then((data)=>{event.value = data; console.log("event.target.result", event.value, data)} );
    
        this.setState({
          file: URL.createObjectURL(event.target.files[0])
        })
      }

    render() {
        console.log("FileWidget props ", this.props);
        return (
            <div>
                <input type="file" required={this.props.required}  onChange={this.handleChange}
                 />
                <img style={{width: '200px'}} src={this.state.file}/>
            </div>
        )
    }
};

class FileForm extends React.Component {
  
    state = {
        formData: {},
        schema : {
            type: 'object',
            required: ['name'],
            properties: {
            name: { type: 'string', title: 'Name', default: '' },
            file: { type: 'string', title: 'File' }
            }
        },
        uiSchema : {
            file: {
              'ui:widget': FileWidget
            }
        }
    };
 
    onSubmit = ({formData}) =>{
        console.log("onSubmit", formData );
        let schema = {
            type: 'object',
            required: ['name'],
            properties: {
              name: { type: 'string', title: 'Name ', default: '' },
              file: { type: 'string', title: 'File ' },
            }
          }
          let uiSchema = {
            file: {
              'ui:widget': FileWidget
            }
          }
        this.setState({formData, schema, uiSchema});
    }

    render() {
        console.log("File Form State", this.state)
        return (
        <div>
            <Form 
            schema={this.state.schema}
            uiSchema={this.state.uiSchema}
            onSubmit={this.onSubmit}
            liveValidate />
            <h4>Submitted file as data URL</h4>
            <pre>{this.state.formData.file}</pre>
        </div>
        );
    }
}

export default FileForm;